from .matchers import *
from nonebot.plugin import PluginMetadata

__version__ = "0.0.1"
__plugin_meta__ = PluginMetadata(
    name="随个人",
    description="Nonebot2 简易插件随个人，随个群友当幸运观众🤪",
    usage="随个人XXX",
    extra={
        "version": __version__,
        "license": "MIT",
        "author": "jcjrobert <jcjrobbie@gmail.com>",
    },
)


from nonebot import on_command
from nonebot.adapters.onebot.v11 import Bot,GroupMessageEvent

import random

from .config import person_config

messages = [
    "{name}觉得{person}就是你要找的人",
    "{name}为你抽了一个人，是{person}",
    "{name}的神之力为你钦定了{person}",
    "让{name}想想，就{person}吧",
    "{name}随机抽取群里一名幸运观众，就这位吧，{person}"
]
nickname = list(person_config.nickname)[0]

get_person = on_command("随个人",priority=12)
@get_person.handle()
async def get_person_send(bot:Bot,event:GroupMessageEvent):
    group_id = event.group_id
    """
    获取群成员列表
    """
    group_member_list = await bot.get_group_member_list(group_id=group_id)
    member = random.choice(group_member_list)
    tosend = random.choice(messages) \
                .replace("{person}",f"{member['card'] if member['card'] else member['nickname']}（{member['user_id']}）") \
                .replace("{name}",nickname)
    await bot.send(event=event,message=tosend,at_sender=True)


from pydantic import BaseModel, Extra
from typing import Set

from nonebot import get_driver

class Config(BaseModel, extra=Extra.ignore):
    nickname: Set[str] = {"Bot"}

person_config = Config.parse_obj(get_driver().config.dict())


import setuptools

with open("README.md", "r", encoding="utf-8", errors="ignore") as f:
    long_description = f.read()
    setuptools.setup(
        name='nonebot-plugin-person',
        version='0.0.1',
        author='jcjrobert',
        author_email='jcjrobbie@gmail.com',
        keywords=["pip", "nonebot2", "nonebot", "随个人"],
        url='https://github.com/jcjrobert/nonebot-plugin-person',
        description='Nonebot2 通用抽图/语音插件',
        long_description=long_description,
        long_description_content_type="text/markdown",
        classifiers=[
            'License :: OSI Approved :: MIT License',
            'Programming Language :: Python :: 3',
        ],
        license='MIT License',
        packages=setuptools.find_packages(),
        include_package_data=True,
        platforms="any",
        install_requires=[
            'nonebot2>=2.0.0-beta.4', 'nonebot-adapter-onebot>=2.0.0-beta.4'
        ]
    )